@@ -76,6 +76,9 @@ def switch_dst_dir(container):  # if app runs in a container
     else:
         ghetto_folder = '//tmp//GhettoRecorder'  # DOCKER
 
+    # set new radio_base_dir class attribute
+    GBase.radio_base_dir = ghetto_folder
+
     source_ini = os.path.dirname(os.path.abspath(__file__)) + '//settings.ini'
     source_script = os.path.dirname(os.path.abspath(__file__)) + '//StartGhetto.sh'
     dst_ini = ghetto_folder + '//settings.ini'
